# Amaryllis

## This module is that calculate insurance value.

## Getting started  

You can install Amaryllis by using pip.  

```
pip install amaryllis
```

## How to use  
・ [interest](/docs/interest.md)  
・ [calc_base](/docs/calc_base.md)  
・ [population](/docs/population.md)  
・ [pension](/docs/pension.md)  
・ [single](/docs/single.md)  













